"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isExecutingStarCommand = isExecutingStarCommand;
exports.isPublishablePackage = isPublishablePackage;
exports.isStarManifest = isStarManifest;
var _core = require("@verdaccio/core");
/**
 * Check whether the package metadata has enough data to be published
 * @param pkg metadata
 */
function isPublishablePackage(pkg) {
  // TODO: we can do better, no need get keys
  const keys = Object.keys(pkg);
  return keys.includes('versions');
}

/**
 * Verify if the user is actually executing an action, to avoid unnecessary calls
 * to the storage.
 * @param localUsers current state at cache
 * @param username user is executing the action
 * @param userIsAddingStar whether user is removing or adding star
 * @returns boolean
 */
function isExecutingStarCommand(localUsers, username, userIsAddingStar) {
  const isExist = typeof localUsers[username] !== 'undefined';
  // fails if user already exist and us trying to add star.
  if (userIsAddingStar && isExist && localUsers[username]) {
    return false;
    // if is not adding a start but user exists (removing star)
  } else if (!userIsAddingStar && isExist) {
    return true;
    // fails if user does not exist and is not adding any star
  } else if (!userIsAddingStar && !isExist) {
    return false;
  }
  return true;
}
function isStarManifest(manifest) {
  return isPublishablePackage(manifest) === false && _core.validatioUtils.isObject(manifest.users);
}
//# sourceMappingURL=star-utils.js.map